@@ -109,12 +109,36 @@ _STOP_WORDS = """
 
 
 def stop_words(add=None, remove=None):
-    """
-    Get the stop words.
+    """Return Cantonese stop words.
 
-    :param add: Stop words to add.
-    :param remove: Stop words to remove.
-    :return: Stop words.
+    .. versionadded:: 2.2.0
+
+    Parameters
+    ----------
+    add : iterable[str], optional
+        Stop words to add.
+    remove : iterable[str], optional
+        Stop words to remove.
+
+    Returns
+    -------
+    set[str]
+
+    Examples
+    --------
+    >>> stop_words = stop_words()
+    >>> len(stop_words)
+    104
+    >>> '香港' in stop_words
+    False
+    >>> stop_words
+    {'一啲', '一定', '不如', '不過', ...}
+    >>>
+    >>> stop_words_1 = stop_words(add='香港')
+    >>> len(stop_words_1)
+    105
+    >>> '香港' in stop_words_1
+    True
     """
     _stop_words = set(_STOP_WORDS)
     if add:
@@ -122,10 +146,11 @@ def stop_words(add=None, remove=None):
             _stop_words.add(add)
         else:
             # assume "add" is an iterable of strings
-            _stop_words = _stop_words | set(add)
+            _stop_words |= set(add)
     if remove:
         if isinstance(remove, str):
             _stop_words.remove(remove)
         else:
-            _stop_words = _stop_words - set(remove)
+            # assume "remove" is an iterable of strings
+            _stop_words -= set(remove)
     return _stop_words
